==> kissme_0.0.31.orig.tar.gz: kissme-0.0.31/vm/native/java_lang_reflect_Field_natives.h <==
	{"java/lang/reflect/Field", "getModifiers", "()I", (void*) Java_java_lang_reflect_Field_getModifiers},
	{"java/lang/reflect/Field", "getType", "()Ljava/lang/Class;", (void*) Java_java_lang_reflect_Field_getType},

  /*get and set methods for Field */ 
	{"java/lang/reflect/Field", "get", "(Ljava/lang/Object;)Ljava/lang/Object;", (void*) Java_java_lang_reflect_Field_get},
	{"java/lang/reflect/Field", "getBoolean", "(Ljava/lang/Object;)Z", (void*) Java_java_lang_reflect_Field_getBoolean},
	{"java/lang/reflect/Field", "getByte", "(Ljava/lang/Object;)B", (void*) Java_java_lang_reflect_Field_getByte},
	{"java/lang/reflect/Field", "getShort", "(Ljava/lang/Object;)S", (void*) Java_java_lang_reflect_Field_getShort},
	{"java/lang/reflect/Field", "getChar", "(Ljava/lang/Object;)C", (void*) Java_java_lang_reflect_Field_getChar},
	{"java/lang/reflect/Field", "getInt", "(Ljava/lang/Object;)I", (void*) Java_java_lang_reflect_Field_getInt},
	{"java/lang/reflect/Field", "getLong", "(Ljava/lang/Object;)J", (void*) Java_java_lang_reflect_Field_getLong},
	{"java/lang/reflect/Field", "getFloat", "(Ljava/lang/Object;)F", (void*) Java_java_lang_reflect_Field_getFloat},
	{"java/lang/reflect/Field", "getDouble", "(Ljava/lang/Object;)D", (void*) Java_java_lang_reflect_Field_getDouble},

	{"java/lang/reflect/Field", "set", "(Ljava/lang/Object;Ljava/lang/Object;)V", (void*) Java_java_lang_reflect_Field_set},
	{"java/lang/reflect/Field", "setBoolean", "(Ljava/lang/Object;Z)V", (void*) Java_java_lang_reflect_Field_setBoolean},
	{"java/lang/reflect/Field", "setByte", "(Ljava/lang/Object;B)V", (void*) Java_java_lang_reflect_Field_setByte},
	{"java/lang/reflect/Field", "setShort", "(Ljava/lang/Object;S)V", (void*) Java_java_lang_reflect_Field_setShort},
	{"java/lang/reflect/Field", "setChar", "(Ljava/lang/Object;C)V", (void*) Java_java_lang_reflect_Field_setChar},
	{"java/lang/reflect/Field", "setInt", "(Ljava/lang/Object;I)V", (void*) Java_java_lang_reflect_Field_setInt},
	{"java/lang/reflect/Field", "setLong", "(Ljava/lang/Object;J)V", (void*) Java_java_lang_reflect_Field_setLong},
	{"java/lang/reflect/Field", "setFloat", "(Ljava/lang/Object;F)V", (void*) Java_java_lang_reflect_Field_setFloat},
	{"java/lang/reflect/Field", "setDouble", "(Ljava/lang/Object;D)V", (void*) Java_java_lang_reflect_Field_setDouble},

==> kissme_0.21.orig.tar.gz: kissme-0.21.orig/vm/native/java_lang_reflect_Field_natives.h <==
	{"java/lang/reflect/Field", "getModifiers", "()I", (void*) Java_java_lang_reflect_Field_getModifiers},
	{"java/lang/reflect/Field", "getType", "()Ljava/lang/Class;", (void*) Java_java_lang_reflect_Field_getType},

  /*get and set methods for Field */ 
	{"java/lang/reflect/Field", "get", "(Ljava/lang/Object;)Ljava/lang/Object;", (void*) Java_java_lang_reflect_Field_get},
	{"java/lang/reflect/Field", "getBoolean", "(Ljava/lang/Object;)Z", (void*) Java_java_lang_reflect_Field_getBoolean},
	{"java/lang/reflect/Field", "getByte", "(Ljava/lang/Object;)B", (void*) Java_java_lang_reflect_Field_getByte},
	{"java/lang/reflect/Field", "getShort", "(Ljava/lang/Object;)S", (void*) Java_java_lang_reflect_Field_getShort},
	{"java/lang/reflect/Field", "getChar", "(Ljava/lang/Object;)C", (void*) Java_java_lang_reflect_Field_getChar},
	{"java/lang/reflect/Field", "getInt", "(Ljava/lang/Object;)I", (void*) Java_java_lang_reflect_Field_getInt},
	{"java/lang/reflect/Field", "getLong", "(Ljava/lang/Object;)J", (void*) Java_java_lang_reflect_Field_getLong},
	{"java/lang/reflect/Field", "getFloat", "(Ljava/lang/Object;)F", (void*) Java_java_lang_reflect_Field_getFloat},
	{"java/lang/reflect/Field", "getDouble", "(Ljava/lang/Object;)D", (void*) Java_java_lang_reflect_Field_getDouble},

	{"java/lang/reflect/Field", "set", "(Ljava/lang/Object;)V", (void*) Java_java_lang_reflect_Field_set},
	{"java/lang/reflect/Field", "setBoolean", "(Ljava/lang/Object;Z)V", (void*) Java_java_lang_reflect_Field_setBoolean},
	{"java/lang/reflect/Field", "setByte", "(Ljava/lang/Object;B)V", (void*) Java_java_lang_reflect_Field_setByte},
	{"java/lang/reflect/Field", "setShort", "(Ljava/lang/Object;S)V", (void*) Java_java_lang_reflect_Field_setShort},
	{"java/lang/reflect/Field", "setChar", "(Ljava/lang/Object;C)V", (void*) Java_java_lang_reflect_Field_setChar},
	{"java/lang/reflect/Field", "setInt", "(Ljava/lang/Object;I)V", (void*) Java_java_lang_reflect_Field_setInt},
	{"java/lang/reflect/Field", "setLong", "(Ljava/lang/Object;J)V", (void*) Java_java_lang_reflect_Field_setLong},
	{"java/lang/reflect/Field", "setFloat", "(Ljava/lang/Object;F)V", (void*) Java_java_lang_reflect_Field_setFloat},
	{"java/lang/reflect/Field", "setDouble", "(Ljava/lang/Object;D)V", (void*) Java_java_lang_reflect_Field_setDouble},
